﻿local PassLoot = LibStub("AceAddon-3.0"):GetAddon("PassLoot");

function PassLoot:ShowTooltip(...)
  if ( select("#", ...) == 0 ) then
    return;
  end
  GameTooltip:SetOwner(PassLoot_MainFrame, "ANCHOR_TOPLEFT");
  GameTooltip:SetText(PassLoot.FontWhite..select(1, ...));
  for i = 2, select("#", ...) do
    GameTooltip:AddLine(PassLoot.FontGold..select(i, ...));
  end
  GameTooltip:Show();
end

--Function to copy tables, since passing tables is always by reference.
function PassLoot:CopyTable(OldDB)
  if ( not OldDB or type(OldDB) ~= "table" ) then
    return OldDB;
  end
  local NewDB;
  NewDB = {};
  for Key, Value in pairs(OldDB) do
    if ( type(Value) ~= "table" ) then
      NewDB[Key] = Value;
    else
      NewDB[Key] = self:CopyTable(Value);
    end
  end
  return NewDB;
end

-- I am going to use this function to scroll text boxes to the left instead of SetCursorPosition()
-- SetCursorPosition(0) requires I ClearFocus(), which will create a loop that I don't really like.
function PassLoot:ScrollLeft(Frame, Elapsed)
  Frame:HighlightText(0,1);
  Frame:Insert(" "..strsub(Frame:GetText(),1,1));
  Frame:HighlightText(0,1);
  Frame:Insert("");
  Frame:SetScript("OnUpdate", nil);
end

function PassLoot:DisplayCurrentRule()
  if ( not self.CurrentRule ) then
    self.CurrentRule = 0;
  end
  self.CurrentOptionFilter = { nil, 0 }; -- Frame, line #
  self:DisplayCurrentOptionFilter();
  if ( self.CurrentRule > 0 ) then
    PassLoot_Rules_Settings_Desc:Show();
    PassLoot_Rules_Settings_Options:Show();
    PassLoot_Rules_Settings_Filters:Show();
    self:Rules_Settings_Options_OnScroll();
    self:Rules_Settings_Filters_OnScroll();
    PassLoot_Rules_Settings_Desc:SetText(self.db.profile.Rules[self.CurrentRule].Desc);
    PassLoot_Rules_Settings_Desc:SetScript("OnUpdate", function(...) self:ScrollLeft(...) end);
  else
    PassLoot_Rules_Settings_Desc:Hide();
    PassLoot_Rules_Settings_Options:Hide();
    PassLoot_Rules_Settings_Filters:Hide();
  end
end

-- Show the widget that is selected
function PassLoot:DisplayCurrentOptionFilter()
  local Widget;
  if ( self.OldOptionFilter ) then
    self.OldOptionFilter:Hide();
  end
  if ( self.CurrentOptionFilter[1] == "Options" ) then
    PassLoot_Rules_Settings_Add:Show();
    PassLoot_Rules_Settings_Remove:Hide();
  elseif ( self.CurrentOptionFilter[1] == "Filters" ) then
    local WidgetKey, Offset = self:GetWidgetFromLineNum(self.CurrentOptionFilter[2]);
    PassLoot_Rules_Settings_Add:Hide();
    PassLoot_Rules_Settings_Remove:Show();
    if ( Offset ) then
      Widget = self.RuleWidgets[WidgetKey];
      Widget:DisplayWidget(Offset);
      Widget:Show();
    end
  else
    PassLoot_Rules_Settings_Add:Hide();
    PassLoot_Rules_Settings_Remove:Hide();
  end
  self.OldOptionFilter = Widget;
end

function PassLoot:SetLootMethod(Frame)
  local _, _, LineNum = string.find(Frame:GetName(), "Line(%d+)");
  local RuleNum = tonumber(LineNum) + FauxScrollFrame_GetOffset(PassLoot_Rules_RuleList_Scroll);
  if ( string.find(Frame:GetName(), "_Pass$") ) then
    if ( self.db.profile.Rules[RuleNum].Loot == "pass" ) then
      self.db.profile.Rules[RuleNum].Loot = "disabled";
    else
      self.db.profile.Rules[RuleNum].Loot = "pass";
    end
    getglobal("PassLoot_Rules_RuleList_ScrollLine"..LineNum.."_Greed"):SetChecked(false);
    getglobal("PassLoot_Rules_RuleList_ScrollLine"..LineNum.."_Need"):SetChecked(false);
  elseif ( string.find(Frame:GetName(), "_Greed$") ) then
    if ( self.db.profile.Rules[RuleNum].Loot == "greed" ) then
      self.db.profile.Rules[RuleNum].Loot = "disabled";
    else
      self.db.profile.Rules[RuleNum].Loot = "greed";
    end
    getglobal("PassLoot_Rules_RuleList_ScrollLine"..LineNum.."_Pass"):SetChecked(false);
    getglobal("PassLoot_Rules_RuleList_ScrollLine"..LineNum.."_Need"):SetChecked(false);
  elseif ( string.find(Frame:GetName(), "_Need$") ) then
    if ( self.db.profile.Rules[RuleNum].Loot == "need" ) then
      self.db.profile.Rules[RuleNum].Loot = "disabled";
    else
      self.db.profile.Rules[RuleNum].Loot = "need";
    end
    getglobal("PassLoot_Rules_RuleList_ScrollLine"..LineNum.."_Pass"):SetChecked(false);
    getglobal("PassLoot_Rules_RuleList_ScrollLine"..LineNum.."_Greed"):SetChecked(false);
  end
end

function PassLoot:SetDesc(Frame)
  if ( self.CurrentRule > 0 ) then
    self.db.profile.Rules[self.CurrentRule].Desc = Frame:GetText();
  end
  Frame:ClearFocus();
  PassLoot:Rules_RuleList_OnScroll();
end

function PassLoot:SetCurrentRule(Frame)
  local Counter;
  local _, _, LineNum = string.find(Frame:GetName(), "Line(%d+)");
  LineNum = tonumber(LineNum);
  self.CurrentRule = LineNum + FauxScrollFrame_GetOffset(PassLoot_Rules_RuleList_Scroll);
  for Counter = 1, self.NumRuleListLines do
    if ( Counter == LineNum ) then
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Counter.."Highlight"):Show();
    else
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Counter.."Highlight"):Hide();
    end
  end
  self:DisplayCurrentRule();
end

function PassLoot:SetCurrentOptionFilter(Frame, Button)
  local Counter;
  local _, _, ParentFrame, LineNum = string.find(Frame:GetName(), "_(%a+)_ScrollLine(%d+)");
  LineNum = tonumber(LineNum);
  self.CurrentOptionFilter = {
    ParentFrame,
    LineNum + FauxScrollFrame_GetOffset(getglobal("PassLoot_Rules_Settings_"..ParentFrame.."_Scroll")),
  };
  if ( Button == "RightButton" and IsShiftKeyDown() and ParentFrame == "Filters" ) then
    self:RemoveFilter();
  else
    for Counter = 1, self.NumOptionFilterLines do
      if ( LineNum == Counter ) then
        if ( ParentFrame == "Options" ) then
          getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Counter.."Highlight"):Show();
          getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Counter.."Highlight"):Hide();
        else
          getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Counter.."Highlight"):Hide();
          getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Counter.."Highlight"):Show();
        end
      else
        getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Counter.."Highlight"):Hide();
        getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Counter.."Highlight"):Hide();
      end
    end
  end
  self:DisplayCurrentOptionFilter();
end

function PassLoot:RemoveFilter()
  if ( self.CurrentRule > 0 and self.CurrentOptionFilter[1] == "Filters" and self.CurrentOptionFilter[2] > 0 ) then
    local WidgetKey, Offset = self:GetWidgetFromLineNum(self.CurrentOptionFilter[2]);
    if ( Offset ) then
      self.RuleWidgets[WidgetKey]:RemoveFilter(Offset);
    else
      for Index = self.RuleWidgets[WidgetKey]:GetNumFilters(), 1, -1 do
        self.RuleWidgets[WidgetKey]:RemoveFilter(Index);
      end
    end
    for Key, Value in pairs(self.RuleWidgets) do
      Value:Hide();
    end
    self.CurrentOptionFilter = { nil, 0 }; -- Frame, line #
    -- self:DisplayCurrentOptionFilter();
    self:Rules_Settings_Options_OnScroll();
    self:Rules_Settings_Filters_OnScroll();
  end
end

function PassLoot:ButtonClick(Frame)
  if ( not self.CurrentRule or not tonumber(self.CurrentRule) ) then
    self.CurrentRule = 0;
  end
  local NumRules, TempDB;
  if ( Frame:GetName() == "PassLoot_Rules_RuleList_Add" ) then
    TempDB = {}
    for Key, Value in ipairs(self.DefaultTemplate) do
      TempDB[Value[1]] = self:CopyTable(Value[2]);
    end
    table.insert(self.db.profile.Rules, TempDB);
    self:Rules_RuleList_OnScroll();
  elseif ( Frame:GetName() == "PassLoot_Rules_RuleList_Remove" ) then
    if ( self.CurrentRule > 0 ) then
      table.remove(self.db.profile.Rules, self.CurrentRule);
      self.CurrentRule = 0;
      self:Rules_RuleList_OnScroll();
      self:DisplayCurrentRule();
    end
  elseif ( Frame:GetName() == "PassLoot_Rules_RuleList_Up" ) then
    if ( self.CurrentRule > 1 ) then
      TempDB = self.db.profile.Rules[self.CurrentRule];
      self.db.profile.Rules[self.CurrentRule] = self.db.profile.Rules[self.CurrentRule - 1];
      self.db.profile.Rules[self.CurrentRule - 1] = TempDB;
      self.CurrentRule = self.CurrentRule - 1;
      self:Rules_RuleList_OnScroll();
      self:DisplayCurrentRule();
    end
  elseif ( Frame:GetName() == "PassLoot_Rules_RuleList_Down" ) then
    if ( self.CurrentRule > 0 and self.CurrentRule < #self.db.profile.Rules ) then
      TempDB = self.db.profile.Rules[self.CurrentRule];
      self.db.profile.Rules[self.CurrentRule] = self.db.profile.Rules[self.CurrentRule + 1];
      self.db.profile.Rules[self.CurrentRule + 1] = TempDB;
      self.CurrentRule = self.CurrentRule + 1;
      self:Rules_RuleList_OnScroll();
      self:DisplayCurrentRule();
    end
  elseif ( Frame:GetName() == "PassLoot_Rules_Settings_Add" ) then
    if ( self.CurrentRule > 0 and self.CurrentOptionFilter[1] == "Options" and self.CurrentOptionFilter[2] > 0 ) then
      self.RuleWidgets[self.CurrentOptionFilter[2]]:AddNewFilter();
      self:Rules_Settings_Filters_OnScroll();
    end
  elseif ( Frame:GetName() == "PassLoot_Rules_Settings_Remove" ) then
    self:RemoveFilter();
  elseif ( Frame:GetName() == "PassLoot_Settings_ModEnabled" ) then
    if ( self:IsEnabled() ) then
      self:Disable();
    else
      self:Enable();
    end
  elseif ( Frame:GetName() == "PassLoot_Settings_Quiet" ) then
    self.db.profile.Quiet = not self.db.profile.Quiet;
  elseif ( Frame:GetName() == "PassLoot_Settings_OutputFrameSticky" ) then
    local SinkOpts = self:GetSinkAce3OptionsDataTable();
    SinkOpts.set({ "Sticky" }, Frame:GetChecked());
    self:DisplayOutputInfo();
  elseif ( Frame:GetName() == "PassLoot_Profiles_Copy" ) then
    if ( PassLoot_Profiles_CopyProfile.value ) then
      self.db:CopyProfile(PassLoot_Profiles_CopyProfile.value);
    end
  elseif ( Frame:GetName() == "PassLoot_Profiles_Delete" ) then
    if ( PassLoot_Profiles_DeleteProfile.value ) then
      self.db:DeleteProfile(PassLoot_Profiles_DeleteProfile.value);
    end
  elseif ( Frame:GetName() == "PassLoot_Profiles_Create" ) then
    if ( PassLoot_Profiles_NewProfileName:GetText() and PassLoot_Profiles_NewProfileName:GetText() ~= "" ) then
      self.db:SetProfile(PassLoot_Profiles_NewProfileName:GetText());
    end
  elseif ( Frame:GetName() == "PassLoot_Profiles_Reset" ) then
    self:ResetProfile();
  elseif ( Frame:GetName() == "PassLoot_MainFrame_Done" ) then
    PassLoot_MainFrame:Hide();
  end
end

function PassLoot:Rules_RuleList_OnScroll()
  local Line, LineNum;
  local NumRules = #self.db.profile.Rules;
  FauxScrollFrame_Update(PassLoot_Rules_RuleList_Scroll, NumRules, self.NumRuleListLines, self.RuleListLineHeight);
  for Line=1, self.NumRuleListLines do
    LineNum = Line + FauxScrollFrame_GetOffset(PassLoot_Rules_RuleList_Scroll);
    if ( LineNum <= NumRules ) then
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."_Text"):SetText(self.db.profile.Rules[LineNum].Desc);
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."_Pass"):SetChecked(false);
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."_Greed"):SetChecked(false);
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."_Need"):SetChecked(false);
      if ( self.db.profile.Rules[LineNum].Loot == "pass" ) then
        getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."_Pass"):SetChecked(true);
      elseif ( self.db.profile.Rules[LineNum].Loot == "greed" ) then
        getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."_Greed"):SetChecked(true);
      elseif ( self.db.profile.Rules[LineNum].Loot == "need" ) then
        getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."_Need"):SetChecked(true);
      end
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line):Show();
      if ( LineNum == self.CurrentRule ) then
        getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."Highlight"):Show();
      else
        getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."Highlight"):Hide();
      end
    else
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line.."Highlight"):Hide();
      getglobal("PassLoot_Rules_RuleList_ScrollLine"..Line):Hide();
    end
  end
end

function PassLoot:Rules_Settings_Options_OnScroll()
  local Line, LineNum;
  local NumOptions = #self.RuleWidgets;
  FauxScrollFrame_Update(PassLoot_Rules_Settings_Options_Scroll, NumOptions, self.NumOptionFilterLines, self.OptionFilterLineHeight);
  for Line=1, self.NumOptionFilterLines do
    LineNum = Line + FauxScrollFrame_GetOffset(PassLoot_Rules_Settings_Options_Scroll);
    if ( LineNum <= NumOptions ) then
      getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Line.."_Text"):SetText(self.RuleWidgets[LineNum].Info[1] or "");
      getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Line):Show();
      if ( self.CurrentOptionFilter[1] == "Options" and self.CurrentOptionFilter[2] == LineNum ) then
        getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Line.."Highlight"):Show();
      else
        getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Line.."Highlight"):Hide();
      end
    else
      getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Line.."Highlight"):Hide();
      getglobal("PassLoot_Rules_Settings_Options_ScrollLine"..Line):Hide();
    end
  end
end

function PassLoot:Rules_Settings_Filters_OnScroll()
  if ( self.CurrentRule < 1 ) then
    return;
  end
  local Line, LineNum;
  local NumLines = 0;
  local WidgetKey, Offset, Text, NumFilters;
  for WidgetKey, WidgetValue in ipairs(self.RuleWidgets) do
    NumFilters = (WidgetValue:GetNumFilters() or 0);
    if ( NumFilters > 0 ) then
      NumLines = NumLines + NumFilters + 1;
    end
  end
  FauxScrollFrame_Update(PassLoot_Rules_Settings_Filters_Scroll, NumLines, self.NumOptionFilterLines, self.OptionFilterLineHeight);
  for Line=1, self.NumOptionFilterLines do
    LineNum = Line + FauxScrollFrame_GetOffset(PassLoot_Rules_Settings_Filters_Scroll);
    if ( LineNum <= NumLines ) then
      WidgetKey, Offset = self:GetWidgetFromLineNum(LineNum);
      if ( Offset ) then
        Text = self.RuleWidgets[WidgetKey]:GetFilterText(Offset) or "Value Error";
      else
        Text = PassLoot.FontGold..(self.RuleWidgets[WidgetKey].Info[1] or "Name Error");
      end
      getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Line.."_Text"):SetText(Text);
      getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Line):Show();
      if ( self.CurrentOptionFilter[1] == "Filters" and self.CurrentOptionFilter[2] == LineNum ) then
        getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Line.."Highlight"):Show();
      else
        getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Line.."Highlight"):Hide();
      end
    else
      getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Line.."Highlight"):Hide();
      getglobal("PassLoot_Rules_Settings_Filters_ScrollLine"..Line):Hide();
    end
  end
end

function PassLoot:GetWidgetFromLineNum(Offset)
  local VariableList, NumFilters;
  for WidgetKey, WidgetValue in ipairs(self.RuleWidgets) do
    NumFilters = WidgetValue:GetNumFilters() or 0;
    if ( NumFilters > 0 ) then
      Offset = Offset - 1;
      if ( Offset == 0 ) then
        return WidgetKey, nil;
      end
    end
    if ( Offset <= NumFilters ) then
      return WidgetKey, Offset;
    else
      Offset = Offset - NumFilters;
    end
  end
end

function PassLoot:DropDown_CurrentProfile_OnClick(Frame)
  self.db:SetProfile(Frame.value);
  -- Don't need to set text, as it is done in the on profile change function
end

function PassLoot:DropDown_CopyProfile_OnClick(Frame)
  if ( select(4, GetBuildInfo()) < 30000 ) then
    UIDropDownMenu_SetText(Frame:GetText(), Frame.owner);
  else
    UIDropDownMenu_SetText(Frame.owner, Frame:GetText());
  end
  getglobal(Frame.owner:GetName()).value = Frame.value;
end

function PassLoot:DropDown_DeleteProfile_OnClick(Frame)
  if ( select(4, GetBuildInfo()) < 30000 ) then
    UIDropDownMenu_SetText(Frame:GetText(), Frame.owner);
  else
    UIDropDownMenu_SetText(Frame.owner, Frame:GetText());
  end
  getglobal(Frame.owner:GetName()).value = Frame.value;
end

function PassLoot:DisplayOutputInfo()
  local SinkOpts = self:GetSinkAce3OptionsDataTable();
  local OutputFrameMain, OutputFrameSub, Sticky = "", "", false;
  local ScrollAreaValues = false;
  for Key, Value in pairs(SinkOpts.args) do
    if ( Key ~= "Sticky" and Key ~= "ScrollArea" ) then
      if ( SinkOpts.get({ Key }) ) then
        OutputFrameMain = Value.name;
        break;
      end
    end
  end
  for Key, Value in pairs(SinkOpts.args.ScrollArea.values) do
    ScrollAreaValues = true;
    break;
  end
  if ( ScrollAreaValues ) then
    PassLoot_Settings_OutputFrameSub:Show();
    OutputFrameSub = SinkOpts.get({ "ScrollArea" });
  else
    PassLoot_Settings_OutputFrameSub:Hide();
  end
  if ( not SinkOpts.args.Sticky.disabled ) then
    PassLoot_Settings_OutputFrameSticky:Show();
    Sticky = SinkOpts.get({ "Sticky" });
  else
    PassLoot_Settings_OutputFrameSticky:Hide();
  end
  if ( select(4, GetBuildInfo()) < 30000 ) then
    UIDropDownMenu_SetText(OutputFrameMain,  PassLoot_Settings_OutputFrameMain);
    UIDropDownMenu_SetText(OutputFrameSub,  PassLoot_Settings_OutputFrameSub);
  else
    UIDropDownMenu_SetText(PassLoot_Settings_OutputFrameMain, OutputFrameMain);
    UIDropDownMenu_SetText(PassLoot_Settings_OutputFrameSub, OutputFrameSub);
  end
  PassLoot_Settings_OutputFrameSticky:SetChecked(Sticky);
end

function PassLoot:DropDown_OutputFrameMain_OnClick(Frame)
  local info = {
    Frame.value.Value
  };
  Frame.value.SetFunc(info, true);
  self:DisplayOutputInfo();
end

function PassLoot:DropDown_OutputFrameSub_OnClick(Frame)
  Frame.value.SetFunc({ "ScrollArea" }, Frame.value.Value);
  self:DisplayOutputInfo();
end

function PassLoot:DropDown_CurrentProfile_Init(Frame, Level)
  local info = {};
  info.checked = false;
  if ( select(4, GetBuildInfo()) < 30000 ) then
    info.func = function(...) self:DropDown_CurrentProfile_OnClick(this, ...) end;
  else
    info.func = function(...) self:DropDown_CurrentProfile_OnClick(...) end;
  end
  info.owner = Frame;
  for Key, Value in pairs(self.db:GetProfiles()) do
    info.text = Value;
    info.value = Value;
    UIDropDownMenu_AddButton(info);
  end
end

function PassLoot:DropDown_CopyProfile_Init(Frame, Level)
  local info = {};
  info.checked = false;
  if ( select(4, GetBuildInfo()) < 30000 ) then
    info.func = function(...) self:DropDown_CopyProfile_OnClick(this, ...) end;
  else
    info.func = function(...) self:DropDown_CopyProfile_OnClick(...) end;
  end
  info.owner = Frame;
  for Key, Value in pairs(self.db:GetProfiles()) do
    info.text = Value;
    info.value = Value;
    if ( Value ~= self.db:GetCurrentProfile() ) then
      UIDropDownMenu_AddButton(info);
    end
  end
end

function PassLoot:DropDown_DeleteProfile_Init(Frame, Level)
  local info = {};
  info.checked = false;
  if ( select(4, GetBuildInfo()) < 30000 ) then
    info.func = function(...) self:DropDown_DeleteProfile_OnClick(this, ...) end;
  else
    info.func = function(...) self:DropDown_DeleteProfile_OnClick(...) end;
  end
  info.owner = Frame;
  for Key, Value in pairs(self.db:GetProfiles()) do
    info.text = Value;
    info.value = Value;
    if ( Value ~= self.db:GetCurrentProfile() ) then
      UIDropDownMenu_AddButton(info);
    end
  end
end

function PassLoot:DropDown_OutputFrameMain_Init(Frame, Level)
  local SinkOpts = self:GetSinkAce3OptionsDataTable();
  local info = {};
  info.checked = false;
  if ( select(4, GetBuildInfo()) < 30000 ) then
    info.func = function(...) self:DropDown_OutputFrameMain_OnClick(this, ...) end;
  else
    info.func = function(...) self:DropDown_OutputFrameMain_OnClick(...) end;
  end
  info.owner = Frame;
  for Key, Value in pairs(SinkOpts.args) do
    if ( Key ~= "Sticky" and Key ~= "ScrollArea" and ( not Value.hidden or ( type(Value.hidden) == "function" and not Value:hidden() ) ) and Value.type == "toggle" and not Value.disabled ) then
      info.text = Value.name;
      info.value = {
        ["SetFunc"] = SinkOpts.set,
        ["Value"] = Key,
      };
      UIDropDownMenu_AddButton(info);
    end
  end
end

function PassLoot:DropDown_OutputFrameSub_Init(Frame, Level)
  local SinkOpts = self:GetSinkAce3OptionsDataTable();
  local info = {};
  info.checked = false;
  if ( select(4, GetBuildInfo()) < 30000 ) then
    info.func = function(...) self:DropDown_OutputFrameSub_OnClick(this, ...) end;
  else
    info.func = function(...) self:DropDown_OutputFrameSub_OnClick(...) end;
  end
  info.owner = Frame;
  for Key, Value in pairs(SinkOpts.args.ScrollArea.values) do
    info.text = Value;
    info.value = {
      ["SetFunc"] = SinkOpts.set,
      ["Value"] = Key,
    };
    UIDropDownMenu_AddButton(info);
  end
end

function PassLoot:TabButtonClick(Frame, TabbedMenuContainer)
  if ( select(4, GetBuildInfo()) < 30000 ) then
    PanelTemplates_Tab_OnClick(TabbedMenuContainer);
  else
    PanelTemplates_Tab_OnClick(Frame, TabbedMenuContainer);
  end
  PassLoot_Rules:Hide();
  PassLoot_Modules:Hide();
  PassLoot_Settings:Hide();
  PassLoot_Profiles:Hide();
  if ( TabbedMenuContainer.selectedTab == 1 ) then
    PassLoot_Rules:Show();
  elseif ( TabbedMenuContainer.selectedTab == 2 ) then
    PassLoot_Modules:Show();
  elseif ( TabbedMenuContainer.selectedTab == 3 ) then
    PassLoot_Settings:Show();
  elseif ( TabbedMenuContainer.selectedTab == 4 ) then
    PassLoot_Profiles:Show();
  end
end

function PassLoot:IsBeta_XMLWorkAround()
  if ( select(4, GetBuildInfo()) >= 30000 ) then
    return true;
  end
  return false;
end
